# Jupyter Community Call June 28

**Date:** June 28, 2022, at 3am Pacific (in your [timezone](https://arewemeetingyet.com/Los%20Angeles/2022-06-28/15:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)** 

**[YouTube Link](https://youtu.be/pyEE4tjsj3U)** 

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

- Steve: coming soon - getting rid of ``setuptools`` for extension authors - work is being coordinated on a PR on [JupyterLab](https://github.com/jupyterlab/jupyterlab/pull/12606)
- Nick: [jupyterlite](https://github.com/jupyterlite/jupyterlite/releases/tag/v0.1.0b10) kernels can now access contents directly 

## Agenda Items

* **Tony** ??? ([how general is the nbformat?](https://gist.github.com/tonyfast/6c236af7dcaa87fc012f31b720575dd7))
    * And where are we going next

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- [My Brainfuck CPU - A simple Processor in Python via MyHDL (part 1)](https://nbviewer.org/github/sandbender/BF_CPU/blob/master/BF_MYHDL_CPU_v2.ipynb)
- [jmshea/digicom-jupyter Digital Communications JupyterLite Site](https://github.com/jmshea/digicom-jupyter)
- [Idea: Binder + JupyterLite = BinderLite? (Jupyter Discourse)](https://discourse.jupyter.org/t/idea-binder-jupyterlite-binderlite/14449)
- [Neal Brennan: 3 Mics](https://www.imdb.com/title/tt6438918/?ref_=nm_flmg_wr_7)
- [Types - Web Assembly](https://webassembly.github.io/spec/core/syntax/types.html)

## Attendees 

|   Name           |           Institution     | GitHub Handle|
|------------------|---------------------------|--------------|
| Steven Silvester | MongoDB                   | @blink1073
| Nick Bollweg     | Georgia Tech              | @bollwyvl 
| A. T. Darian| QuantStack | @afshin | 
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf 
| Tony Fast | Quansight | @tonyfast |

Plus 1 more.